# Changelog

## Intake-thredds v2022.8.19

([full changelog](https://github.com/intake/intake-thredds/compare/v2021.6.16...af8a621300e48e639c86ce0be998ecfe3f644932))

### Enhancements made

- check `type` of `path` [#63](https://github.com/intake/intake-thredds/pull/63) ([@aaronspring](https://github.com/aaronspring))
- Add intake_xarray_kwargs to ThreddsCatalog [#52](https://github.com/intake/intake-thredds/pull/52) ([@andersy005](https://github.com/andersy005))
- import auto tqdm [#45](https://github.com/intake/intake-thredds/pull/45) ([@raybellwaves](https://github.com/raybellwaves))

### Maintenance and upkeep improvements

- Cancel redundant CI jobs [#94](https://github.com/intake/intake-thredds/pull/94) ([@andersy005](https://github.com/andersy005))
- [pre-commit.ci] pre-commit autoupdate [#93](https://github.com/intake/intake-thredds/pull/93) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#92](https://github.com/intake/intake-thredds/pull/92) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump pypa/gh-action-pypi-publish from 1.5.0 to 1.5.1 [#91](https://github.com/intake/intake-thredds/pull/91) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#90](https://github.com/intake/intake-thredds/pull/90) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#89](https://github.com/intake/intake-thredds/pull/89) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#88](https://github.com/intake/intake-thredds/pull/88) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump styfle/cancel-workflow-action from 0.9.1 to 0.10.0 [#87](https://github.com/intake/intake-thredds/pull/87) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#86](https://github.com/intake/intake-thredds/pull/86) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#85](https://github.com/intake/intake-thredds/pull/85) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump actions/setup-python from 3 to 4 [#84](https://github.com/intake/intake-thredds/pull/84) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#83](https://github.com/intake/intake-thredds/pull/83) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 3.0.0 to 3.1.0 [#82](https://github.com/intake/intake-thredds/pull/82) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#81](https://github.com/intake/intake-thredds/pull/81) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 2.1.0 to 3.0.0 [#80](https://github.com/intake/intake-thredds/pull/80) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#79](https://github.com/intake/intake-thredds/pull/79) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#78](https://github.com/intake/intake-thredds/pull/78) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#77](https://github.com/intake/intake-thredds/pull/77) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#75](https://github.com/intake/intake-thredds/pull/75) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#71](https://github.com/intake/intake-thredds/pull/71) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Add pyupgrade to the list of pre-commit hooks [#69](https://github.com/intake/intake-thredds/pull/69) ([@andersy005](https://github.com/andersy005))
- Remove linting workflow [#66](https://github.com/intake/intake-thredds/pull/66) ([@andersy005](https://github.com/andersy005))
- [pre-commit.ci] pre-commit autoupdate [#62](https://github.com/intake/intake-thredds/pull/62) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#61](https://github.com/intake/intake-thredds/pull/61) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#59](https://github.com/intake/intake-thredds/pull/59) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#58](https://github.com/intake/intake-thredds/pull/58) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#57](https://github.com/intake/intake-thredds/pull/57) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#56](https://github.com/intake/intake-thredds/pull/56) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#55](https://github.com/intake/intake-thredds/pull/55) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#54](https://github.com/intake/intake-thredds/pull/54) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 2.0.3 to 2.1.0 [#53](https://github.com/intake/intake-thredds/pull/53) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#50](https://github.com/intake/intake-thredds/pull/50) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Update pre-commit hooks [#44](https://github.com/intake/intake-thredds/pull/44) ([@andersy005](https://github.com/andersy005))

### Documentation improvements

- Use furo theme and update RTD config to use mamba [#76](https://github.com/intake/intake-thredds/pull/76) ([@andersy005](https://github.com/andersy005))
- check `type` of `path` [#63](https://github.com/intake/intake-thredds/pull/63) ([@aaronspring](https://github.com/aaronspring))

### Other merged PRs

- Bump actions/checkout from 2 to 3 [#73](https://github.com/intake/intake-thredds/pull/73) ([@dependabot](https://github.com/dependabot))
- Bump actions/setup-python from 2 to 3 [#72](https://github.com/intake/intake-thredds/pull/72) ([@dependabot](https://github.com/dependabot))
- Update refs: NCAR/intake-thredds -> intake/intake-thredds [#68](https://github.com/intake/intake-thredds/pull/68) ([@andersy005](https://github.com/andersy005))
- Bump pypa/gh-action-pypi-publish from 1.4.2 to 1.5.0 [#64](https://github.com/intake/intake-thredds/pull/64) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#60](https://github.com/intake/intake-thredds/pull/60) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#49](https://github.com/intake/intake-thredds/pull/49) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 2.0.2 to 2.0.3 [#48](https://github.com/intake/intake-thredds/pull/48) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#47](https://github.com/intake/intake-thredds/pull/47) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump styfle/cancel-workflow-action from 0.9.0 to 0.9.1 [#46](https://github.com/intake/intake-thredds/pull/46) ([@dependabot](https://github.com/dependabot))
- Bump codecov/codecov-action from 1 to 2.0.2 [#43](https://github.com/intake/intake-thredds/pull/43) ([@dependabot](https://github.com/dependabot))
- Update changelog in preparation for new release [#42](https://github.com/intake/intake-thredds/pull/42) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/intake/intake-thredds/graphs/contributors?from=2021-06-16&to=2022-08-19&type=c))

[@aaronspring](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Aaaronspring+updated%3A2021-06-16..2022-08-19&type=Issues) | [@andersy005](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Aandersy005+updated%3A2021-06-16..2022-08-19&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Adependabot+updated%3A2021-06-16..2022-08-19&type=Issues) | [@dopplershift](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Adopplershift+updated%3A2021-06-16..2022-08-19&type=Issues) | [@martindurant](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Amartindurant+updated%3A2021-06-16..2022-08-19&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Apre-commit-ci+updated%3A2021-06-16..2022-08-19&type=Issues) | [@rabernat](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Arabernat+updated%3A2021-06-16..2022-08-19&type=Issues) | [@raybellwaves](https://github.com/search?q=repo%3Aintake%2Fintake-thredds+involves%3Araybellwaves+updated%3A2021-06-16..2022-08-19&type=Issues)

## Intake-thredds v2021.6.16

([full changelog](https://github.com/intake/intake-thredds/compare/4fb261a1f131cefd1083a66b7a10fe1a30eaaaa8...ff4d2720b95077254c0eb184c9ddfe0b3dfc7ca0))

### Enhancements made

- Add tqdm to requirements [#41](https://github.com/intake/intake-thredds/pull/41) ([@raybellwaves](https://github.com/raybellwaves))
- Allow `xarray_kwargs` for {py:class}`~intake_thredds.source.THREDDSMergedSource` [#32](https://github.com/intake/intake-thredds/pull/32) ([@aaronspring](https://github.com/aaronspring))
- Allow `concat_kwargs` for {py:class}`~intake_thredds.source.THREDDSMergedSource` [#34](https://github.com/intake/intake-thredds/pull/34) ([@aaronspring](https://github.com/aaronspring))

### Maintenance and upkeep improvements

- Bump pre-commit/action from v2.0.2 to v2.0.3 [#31](https://github.com/intake/intake-thredds/pull/31) ([@dependabot](https://github.com/dependabot))
- Bump styfle/cancel-workflow-action from 0.8.0 to 0.9.0 [#29](https://github.com/intake/intake-thredds/pull/29) ([@dependabot](https://github.com/dependabot))
- Bump pre-commit/action from v2.0.0 to v2.0.2 [#28](https://github.com/intake/intake-thredds/pull/28) ([@dependabot](https://github.com/dependabot))

### Documentation improvements

- DOC: GEFS example [#40](https://github.com/intake/intake-thredds/pull/40) ([@raybellwaves](https://github.com/raybellwaves))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/intake/intake-thredds/graphs/contributors?from=2021-02-17&to=2021-06-16&type=c))

[@aaronspring](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Aaaronspring+updated%3A2021-02-17..2021-06-16&type=Issues) | [@andersy005](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Aandersy005+updated%3A2021-02-17..2021-06-16&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Adependabot+updated%3A2021-02-17..2021-06-16&type=Issues) | [@raybellwaves](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Araybellwaves+updated%3A2021-02-17..2021-06-16&type=Issues)

## Intake-thredds v2021.2.17

([full changelog](https://github.com/intake/intake-thredds/compare/792fdc08e7fbbf66455fe554ca9a0f1f8a14ae32...ccb3c469a07cc7adf058ce0f8ba41197ebc5b7c7))

### Features

- Turn off notebook execution [#22](https://github.com/intake/intake-thredds/pull/22) ([@andersy005](https://github.com/andersy005))
- Add driver and simplecache example [#20](https://github.com/intake/intake-thredds/pull/20) ([@aaronspring](https://github.com/aaronspring))
- Add documentation [#19](https://github.com/intake/intake-thredds/pull/19) ([@andersy005](https://github.com/andersy005))
- 💚 Update Continuous Integration [#18](https://github.com/intake/intake-thredds/pull/18) ([@andersy005](https://github.com/andersy005))
- Add LICENSE [#17](https://github.com/intake/intake-thredds/pull/17) ([@andersy005](https://github.com/andersy005))
- Docs: Use markdown via myst-parser [#16](https://github.com/intake/intake-thredds/pull/16) ([@andersy005](https://github.com/andersy005))
- Allow simplecache [#14](https://github.com/intake/intake-thredds/pull/14) ([@aaronspring](https://github.com/aaronspring))
- options for combine_by_coords [#13](https://github.com/intake/intake-thredds/pull/13) ([@aaronspring](https://github.com/aaronspring))
- Pass kwargs to Catalog [#12](https://github.com/intake/intake-thredds/pull/12) ([@martindurant](https://github.com/martindurant))
- 💚 Migrate CI from CircleCI to GHA [#10](https://github.com/intake/intake-thredds/pull/10) ([@andersy005](https://github.com/andersy005))
- Use opendap [#7](https://github.com/intake/intake-thredds/pull/7) ([@aaronspring](https://github.com/aaronspring))
- Add tests [#5](https://github.com/intake/intake-thredds/pull/5) ([@andersy005](https://github.com/andersy005))
- CI & RTD configurations Overhaul [#4](https://github.com/intake/intake-thredds/pull/4) ([@andersy005](https://github.com/andersy005))
- Add `THREDDSMergedSource` implementation [#3](https://github.com/intake/intake-thredds/pull/3) ([@martindurant](https://github.com/martindurant))
- Add example [#2](https://github.com/intake/intake-thredds/pull/2) ([@martindurant](https://github.com/martindurant))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/intake/intake-thredds/graphs/contributors?from=2019-01-05&to=2021-02-18&type=c))

[@aaronspring](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Aaaronspring+updated%3A2019-01-05..2021-02-18&type=Issues) | [@andersy005](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Aandersy005+updated%3A2019-01-05..2021-02-18&type=Issues) | [@dopplershift](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Adopplershift+updated%3A2019-01-05..2021-02-18&type=Issues) | [@martindurant](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Amartindurant+updated%3A2019-01-05..2021-02-18&type=Issues) | [@pbranson](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Apbranson+updated%3A2019-01-05..2021-02-18&type=Issues) | [@rabernat](https://github.com/search?q=repo%3ANCAR%2Fintake-thredds+involves%3Arabernat+updated%3A2019-01-05..2021-02-18&type=Issues)
